==> intelmq-2.2.0.tar.gz: intelmq-2.2.0/intelmq/lib/exceptions.py <==
# -*- coding: utf-8 -*-
'''
    IntelMQ Exception Class
'''
import traceback

from typing import Any, Optional

__all__ = ['InvalidArgument', 'ConfigurationError', 'IntelMQException',
           'IntelMQHarmonizationException', 'InvalidKey', 'InvalidValue',
           'KeyExists', 'KeyNotExists', 'PipelineError',
           'MissingDependencyError',
           ]


class IntelMQException(Exception):

    def __init__(self, message):
        super().__init__(message)


'''
    IntelMQ Exception SubClasses
'''


class InvalidArgument(IntelMQException):

    def __init__(self, argument: Any, got: Any = None, expected=None,
                 docs: str = None):
        message = "Argument {} is invalid.".format(repr(argument))
        if expected is list:
            message += " Should be one of: {}.".format(list)
        elif expected:  # not None
            message += " Should be of type: {}.".format(expected)
        if got:
            message += " Got {}.".format(repr(got))
        if docs:
            message += " For more information see {}".format(docs)
        super().__init__(message)


class PipelineError(IntelMQException):

    def __init__(self, argument: Exception):
        if type(argument) is type and issubclass(argument, Exception):
            message = "pipeline failed - %s" % traceback.format_exc(argument)
        else:
            message = "pipeline failed - %s" % repr(argument)
        super().__init__(message)


class ConfigurationError(IntelMQException):

    def __init__(self, config: str, argument: str):
        message = "%s configuration failed - %s" % (config, argument)
        super().__init__(message)


class PipelineFactoryError(IntelMQException):
    pass


'''
    IntelMQ Harmonization Exception Class
'''


class IntelMQHarmonizationException(IntelMQException):

    def __init__(self, message):
        super().__init__(message)


'''
    IntelMQ Harmonization Exception sub classes
'''


class InvalidValue(IntelMQHarmonizationException):

    def __init__(self, key: str, value: str, reason: Any = None):
        message = ("invalid value {value!r} ({type}) for key {key!r}{reason}"
                   "".format(value=value, type=type(value), key=key,
                             reason=': ' + reason if reason else ''))
        super().__init__(message)


class InvalidKey(IntelMQHarmonizationException, KeyError):

    def __init__(self, key: str):
        message = "invalid key %s" % repr(key)
        super().__init__(message)


class KeyExists(IntelMQHarmonizationException):

    def __init__(self, key: str):
        message = "key %s already exists" % repr(key)
        super().__init__(message)


class KeyNotExists(IntelMQHarmonizationException):

    def __init__(self, key: str):
        message = "key %s not exists" % repr(key)
        super().__init__(message)


class MissingDependencyError(IntelMQException):
    """
    A missing dependency was detected. Log instructions on installation.
    """
    def __init__(self, dependency: str, version: Optional[str] = None,
                 installed: Optional[str] = None,
                 additional_text: Optional[str] = None):
        """
        Parameters
        ----------
        dependency : str
            The dependency name.
        version : Optional[str], optional
            The required version. The default is None.
        installed : Optional[str], optional
            The currently installed version. Requires 'version' to be given The default is None.
        additional_text : Optional[str], optional
            Arbitrary additional text to show. The default is None.

        Returns
        -------
        IntelMQException: with prepared text

        """
        appendix = ""
        if version:
            higher = " or higher" if not any(x in version for x in '<>=') else ""
            appendix = (" Please note that this bot requires "
                        "{dependency} version {version}{higher}!"
                        "".format(dependency=dependency,
                                  version=version,
                                  higher=higher))
            if installed:
                if isinstance(installed, tuple):
                    installed = ".".join(map(str, installed))
                appendix = appendix + (" Installed is version {installed!r}."
                                       "".format(installed=installed))
        if additional_text:
            appendix = "%s %s" % (appendix, additional_text)
        message = ("Could not load dependency {dependency!r}, please install it "
                   "with apt/yum/dnf/zypper (possibly named "
                   "python3-{dependency}) or pip3.{appendix}"
                   "".format(dependency=dependency,
                             appendix=appendix))
        super().__init__(message)


class DecodingError(IntelMQException, ValueError):
    """
    This is a separate Error to distinguish it from other exceptions as it is
    unrecoverable.
    """
    def __init__(self, encodings=None, exception: UnicodeDecodeError = None,
                 object: bytes = None):
        self.object = object
        suffix = []
        if encodings:
            suffix.append("with given encodings %r" % encodings)
        if exception:
            suffix.append('at position %s with length %d (%r)'
                          '' % (exception.start, exception.end,
                                exception.object[exception.start:exception.end]))
            suffix.append('with reason %r' % exception.reason)
        suffix = (' ' + ' '.join(suffix)) if suffix else ''
        super().__init__("Could not decode string%s." % suffix)

==> intelmq-3.1.0.tar.gz: intelmq-3.1.0/intelmq/lib/exceptions.py <==
# SPDX-FileCopyrightText: 2015 Dognaedis
#
# SPDX-License-Identifier: AGPL-3.0-or-later

# -*- coding: utf-8 -*-
'''
    IntelMQ Exception Class
'''
from typing import Any, Optional, Union

__all__ = ['InvalidArgument', 'ConfigurationError', 'IntelMQException',
           'IntelMQHarmonizationException', 'InvalidKey', 'InvalidValue',
           'KeyExists', 'KeyNotExists', 'PipelineError',
           'MissingDependencyError',
           ]


class IntelMQException(Exception):

    def __init__(self, message):
        super().__init__(message)


'''
    IntelMQ Exception SubClasses
'''


class InvalidArgument(IntelMQException):

    def __init__(self, argument: Any, got: Any = None, expected=None,
                 docs: str = None):
        message = f"Argument {repr(argument)} is invalid."
        if expected is list:
            message += f" Should be one of: {list}."
        elif expected:  # not None
            message += f" Should be of type: {expected}."
        if got:
            message += f" Got {repr(got)}."
        if docs:
            message += f" For more information see {docs}"
        super().__init__(message)


class PipelineError(IntelMQException):

    def __init__(self, argument: Union[str, Exception]):
        message = "pipeline failed - %s" % repr(argument)
        super().__init__(message)


class ConfigurationError(IntelMQException):

    def __init__(self, config: str, argument: str):
        message = f"{config} configuration failed - {argument}"
        super().__init__(message)


class PipelineFactoryError(IntelMQException):
    pass


'''
    IntelMQ Harmonization Exception Class
'''


class IntelMQHarmonizationException(IntelMQException):

    def __init__(self, message):
        super().__init__(message)


'''
    IntelMQ Harmonization Exception sub classes
'''


class InvalidValue(IntelMQHarmonizationException):

    def __init__(self, key: str, value: str, reason: Any = None, object: bytes = None):
        message = ("invalid value {value!r} ({type}) for key {key!r}{reason}"
                   "".format(value=value, type=type(value), key=key,
                             reason=': ' + reason if reason else ''))
        self.object = object
        super().__init__(message)


class InvalidKey(IntelMQHarmonizationException, KeyError):

    def __init__(self, key: str):
        message = "invalid key %s" % repr(key)
        super().__init__(message)


class KeyExists(IntelMQHarmonizationException):

    def __init__(self, key: str):
        message = "key %s already exists" % repr(key)
        super().__init__(message)


class KeyNotExists(IntelMQHarmonizationException):

    def __init__(self, key: str):
        message = "key %s not exists" % repr(key)
        super().__init__(message)


class MissingDependencyError(IntelMQException):
    """
    A missing dependency was detected. Log instructions on installation.
    """
    def __init__(self, dependency: str, version: Optional[str] = None,
                 installed: Optional[str] = None,
                 additional_text: Optional[str] = None):
        """
        Parameters:
            dependency (str): The dependency name.
            version (Optional[str], optional): The required version. The default is None.
            installed (Optional[str], optional)
                The currently installed version. Requires 'version' to be given The default is None.
            additional_text (Optional[str], optional):
                Arbitrary additional text to show. The default is None.

        Returns:
            IntelMQException: with prepared text
        """
        appendix = ""
        if version:
            higher = " or higher" if not any(x in version for x in '<>=') else ""
            appendix = (" Please note that this bot requires "
                        "{dependency} version {version}{higher}!"
                        "".format(dependency=dependency,
                                  version=version,
                                  higher=higher))
            if installed:
                if isinstance(installed, tuple):
                    installed = ".".join(map(str, installed))
                appendix = appendix + (" Installed is version {installed!r}."
                                       "".format(installed=installed))
        if additional_text:
            appendix = f"{appendix} {additional_text}"
        message = ("Could not load dependency {dependency!r}, please install it "
                   "with apt/yum/dnf/zypper (possibly named "
                   "python3-{dependency}) or pip3.{appendix}"
                   "".format(dependency=dependency,
                             appendix=appendix))
        super().__init__(message)


class DecodingError(IntelMQException, ValueError):
    """
    This is a separate Error to distinguish it from other exceptions as it is
    unrecoverable.
    """
    def __init__(self, encodings=None, exception: UnicodeDecodeError = None,
                 object: bytes = None):
        self.object = object
        suffixes = []
        if encodings:
            suffixes.append("with given encodings %r" % encodings)
        if exception:
            suffixes.append('at position %s with length %d (%r)'
                            '' % (exception.start, exception.end,
                                  exception.object[exception.start:exception.end]))
            suffixes.append('with reason %r' % exception.reason)
        suffix = (' ' + ' '.join(suffixes)) if suffixes else ''
        super().__init__("Could not decode string%s." % suffix)
